"""
Mixture of factor analyzers.

"""

from .mofa import Mofa
